@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Catalyst;
 
-our $VERSION = '0.02';
+our $VERSION = '0.0.3';
 
 # hide debug output at startup
 {
@@ -36,6 +36,14 @@ TestApp->config(
     }
 );
 
+VERSION_MADNESS: {
+    use version;
+    my $vstring = version->new($VERSION)->normal;
+    __PACKAGE__->config(
+        version => $vstring
+    );
+}
+
 TestApp->setup(
     qw<
         -Debug
@@ -43,6 +51,10 @@ TestApp->setup(
         ErrorCatcher
         ConfigLoader
         Authentication
+
+        Session
+        Session::Store::File
+        Session::State::Cookie
     >
 );
 
